# CHANGELOG

## [0.4.0] - 2024-6-18

### Added
* Add support for 2D-cav-LP by @NoahDornhecker in https://github.com/BenediktBurger/snlo-helper/pull/4

**Full Changelog**: https://github.com/BenediktBurger/snlo-helper/compare/v0.3.0...v0.4.0


## [0.3.0] - 2024-05-27

### Added
* Add Qmix & PW-OPO-BB support by @NoahDornhecker in https://github.com/BenediktBurger/snlo-helper/pull/3
* Add license by @BenediktBurger in https://github.com/BenediktBurger/snlo-helper/pull/2

### New Contributors
* @BenediktBurger made their first contribution in https://github.com/BenediktBurger/snlo-helper/pull/2
* @NoahDornhecker made their first contribution in https://github.com/BenediktBurger/snlo-helper/pull/3

**Full Changelog**: https://github.com/BenediktBurger/snlo-helper/compare/v0.2.0...v0.3.0


## [0.2.0] - 2024-05-07

_Completely restructured package for easier maintenance and extension._

**Full Changelog**: https://github.com/BenediktBurger/snlo-helper/compare/v0.1.0...v0.2.0


## [0.1.0] - 2024-04-17

_Initial release_


[0.4.0]: https://github.com/BenediktBurger/snlo-helper/releases/tag/v0.4.0
[0.3.0]: https://github.com/BenediktBurger/snlo-helper/releases/tag/v0.3.0
[0.2.0]: https://github.com/BenediktBurger/snlo-helper/releases/tag/v0.2.0
[0.1.0]: https://github.com/BenediktBurger/snlo-helper/releases/tag/v0.1.0
